# Styles and Patterns
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/styles-and-patterns#overview)
  * [Available Templates](https://help.sap.com/docs/leanix/ea/styles-and-patterns#available-templates)
  * [Related Information](https://help.sap.com/docs/leanix/ea/styles-and-patterns#related-information)


Standardize the style and format of the fact sheets you create in SAP LeanIX. This ensures brand alignment and simplifies the visualization of complex data flows.
